v0.4.1
======

:Date: 2025-05-20 (Asia/Tokyo)

Fixes
-----

* [ `#6`_ ] Simplify process to build href of page with other languages.

  .. _#6: https://github.com/atsphinx/mini18n/issues/6

Others
------

* Mark to support python 3.13.
* Mark as beta product.
* Update workspace environment.

v0.4.0
======

:Date: 2024-05-16 (JST)

Features
--------

* Widget on document remembers selected language when users select it.
